@@ -10,11 +10,9 @@
 #define __INC_mwdg_ctl_arg_view_card_hpp__
 
 #include "mwdg/ctl_arg_view.hpp"
+#include <QModelIndex>
 
 // Forward declaration
-namespace QSnd {
-	class Cards_Model;
-}
 namespace MWdg {
 	class Controls_View;
 }
@@ -38,9 +36,6 @@ class CTL_Arg_View_Card :
 	CTL_Arg_View_Card (
 		QWidget * parent_n = 0 );
 
-	QString
-	arg_string ( ) const;
-
 	void
 	set_arg_string (
 		const QString & str_n );
@@ -50,13 +45,19 @@ class CTL_Arg_View_Card :
 	protected:
 
 	void
-	ctl_db_changed ( );
+	cards_model_changed ( );
+
+
+	// Protected methods
+	protected slots:
+
+	void
+	read_view_selection ( );
 
 
 	// Private attributes
 	private:
 
-	::QSnd::Cards_Model * _cards_model;
 	::MWdg::Controls_View * _ctl_view;
 };
 
