@@ -20,24 +20,33 @@ CTL_Arg_View_String::CTL_Arg_View_String (
 ::MWdg::CTL_Arg_View ( parent_n )
 {
 	_ledit = new QLineEdit;
+	_ledit_signal_block = false;
+
 	connect ( _ledit, SIGNAL ( editingFinished() ),
-		this, SIGNAL ( sig_arg_changed() ) );
+		this, SLOT ( input_string_changed() ) );
 	lay_content()->addWidget ( _ledit );
 }
 
-
-QString
-CTL_Arg_View_String::arg_string ( ) const
-{
-	return _ledit->text();
-}
-
-
 void
 CTL_Arg_View_String::set_arg_string (
 	const QString & str_n )
 {
-	_ledit->setText ( str_n );
+	if ( set_arg_string_private ( str_n ) ) {
+		{
+			_ledit_signal_block = true;
+			_ledit->setText ( str_n );
+			_ledit_signal_block = false;
+		}
+		emit sig_arg_changed();
+	}
+}
+
+void
+CTL_Arg_View_String::input_string_changed ( )
+{
+	if ( !_ledit_signal_block ) {
+		set_arg_string ( _ledit->text() );
+	}
 }
 
 
